@@ -109,13 +109,13 @@ where
             GenericDecimal(ref fraction, precision) => {
                 let prec = precision.into();
                 let debug_prec = f.precision().unwrap_or(32);
+                let value = format!("{:.1$}", fraction, prec);
+                let debug_value = format!("{:.1$}", fraction, debug_prec);
+
                 write!(
                     f,
                     "GenericDecimal({} | prec={}; {:?}; {})",
-                    format!("{:.1$}", fraction, prec),
-                    prec,
-                    fraction,
-                    format!("{:.1$}", fraction, debug_prec)
+                    value, prec, fraction, debug_value
                 )
             }
         }
@@ -447,6 +447,7 @@ where
 }
 
 dec_impl!(impl_trait_cmp; PartialOrd; partial_cmp; Option<Ordering>);
+dec_impl!(impl_trait_cmp; Ord; cmp; Ordering);
 
 impl<T, P> PartialEq for GenericDecimal<T, P>
 where
@@ -819,11 +820,11 @@ where
     P: Copy + GenericInteger + Into<usize>,
 {
     /// Returns Some(Sign) of the decimal, or None if NaN is the value
-    pub fn sign(&self) -> Option<Sign>
+    pub const fn sign(&self) -> Option<Sign>
     where
         T: CheckedAdd + CheckedMul + CheckedSub,
     {
-        self.apply_ref(|f, _| f.sign())
+        self.0.sign()
     }
 
     /// Sets representational precision for the Decimal
@@ -868,7 +869,7 @@ where
     }
 
     /// Returns the current representational precision for the Decimal
-    pub fn get_precision(&self) -> P {
+    pub const fn get_precision(&self) -> P {
         match self {
             GenericDecimal(_, precision) => *precision,
         }
@@ -969,24 +970,24 @@ where
         GenericDecimal(GenericFraction::min_positive_value(), P::max_value())
     }
 
-    pub fn is_nan(&self) -> bool {
-        self.apply_ref(|f, _| f.is_nan())
+    pub const fn is_nan(&self) -> bool {
+        self.0.is_nan()
     }
 
-    pub fn is_infinite(&self) -> bool {
-        self.apply_ref(|f, _| f.is_infinite())
+    pub const fn is_infinite(&self) -> bool {
+        self.0.is_infinite()
     }
 
-    pub fn is_finite(&self) -> bool {
-        self.apply_ref(|f, _| f.is_finite())
+    pub const fn is_finite(&self) -> bool {
+        self.0.is_finite()
     }
 
     pub fn is_normal(&self) -> bool {
-        self.apply_ref(|f, _| f.is_normal())
+        self.0.is_normal()
     }
 
     pub fn classify(&self) -> FpCategory {
-        self.apply_ref(|f, _| f.classify())
+        self.0.classify()
     }
 
     pub fn floor(&self) -> Self {
@@ -1025,12 +1026,12 @@ where
         self.map_ref(|f| f.signum())
     }
 
-    pub fn is_sign_positive(&self) -> bool {
-        self.apply_ref(|f, _| f.is_sign_positive())
+    pub const fn is_sign_positive(&self) -> bool {
+        self.0.is_sign_positive()
     }
 
-    pub fn is_sign_negative(&self) -> bool {
-        self.apply_ref(|f, _| f.is_sign_negative())
+    pub const fn is_sign_negative(&self) -> bool {
+        self.0.is_sign_negative()
     }
 
     pub fn mul_add(&self, a: Self, b: Self) -> Self {
@@ -1059,51 +1060,13 @@ where
         }
     }
 
+    #[deprecated(note = "Use `match decimal {GenericDecimal(fraction, precision) => ... }`")]
     pub fn apply_ref<R>(&self, fun: impl FnOnce(&GenericFraction<T>, P) -> R) -> R {
         match self {
             GenericDecimal(fra, pres) => fun(fra, *pres),
         }
     }
 
-    #[deprecated(note = "Use `FromStr::from_str` instead")]
-    pub fn from_decimal_str(val: &str) -> Result<Self, error::ParseError>
-    where
-        T: CheckedAdd + CheckedMul + CheckedSub,
-        P: From<u8> + CheckedAdd,
-    {
-        if val == "NaN" {
-            Ok(Self::nan())
-        } else if val == "-inf" {
-            Ok(Self::neg_infinity())
-        } else if val == "+inf" || val == "inf" {
-            Ok(Self::infinity())
-        } else {
-            let precision: P = if let Some(split_idx) = val.find('.') {
-                let mut prec_iter = val.len() - split_idx - 1;
-                let mut precision: P = P::zero();
-
-                loop {
-                    if prec_iter == 0 {
-                        break;
-                    }
-                    prec_iter -= 1;
-
-                    if let Some(p) = precision.checked_add(&P::one()) {
-                        precision = p;
-                    } else {
-                        break;
-                    }
-                }
-
-                precision
-            } else {
-                P::zero()
-            };
-
-            Ok(GenericDecimal::from_str_radix(val, 10)?.set_precision(precision))
-        }
-    }
-
     /// Convert from a GenericFraction
     ///
     /// Automatically calculates precision, so for "bad" numbers
